---
title: <span class="badge object-type-scalar"></span> Gallons
---
# <span class="badge object-type-scalar"></span> Gallons

Volume: gallons

## Definition

```python
# Volume: gallons
Gallons: typing.Literal["gallons"] = "gallons"
```
